
Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


References
----------
.. image:: https://zenodo.org/badge/doi/10.5281/zenodo.593721.svg
   :target: https://doi.org/10.5281/zenodo.593721

The Elastic package should be cited using one or both of the following papers 
(TiC, ZrC) and its own reference.: 

.. [Elastic] P.T. Jochym, 
        *Module for calculating elastic tensor of crystals*,
        software, https://github.com/jochym/Elastic/,
        `doi:10.5281/zenodo.593721 <http://dx.doi.org/10.5281/zenodo.593721>`_.
.. [TiC] P.T. Jochym, K. Parlinski and M. Sternik, 
        *TiC lattice dynamics from ab initio calculations*, 
        European Physical Journal B; **10**, 1 (1999) 9-13 ; 
        `doi:10.1007/s100510050823 <http://dx.doi.org/10.1007/s100510050823>`_
.. [ZrC] P.T. Jochym and K. Parlinski, 
        *Ab initio lattice dynamics and elastic constants of ZrC*, 
        European Physical Journal B; **15**, 2 (2000) 265-268 ; 
        `doi:10.1007/s100510051124 <http://dx.doi.org/10.1007/s100510051124>`_
.. [LL] L.D. Landau, E.M. Lifszyc, `Theory of elasticity <http://books.google.com/books?id=tpY-VkwCkAIC>`_, Elsevier (1986) ; ISBN: 075062633X, 9780750626330
.. [SVD] G. Golub and W. Kahan, 
        *Calculating the Singular Values and Pseudo-Inverse of a Matrix*, 
        J. Soc. Indus,.Appl. Math.: Ser. B **2**, (1964) pp. 205-224 ;
        `doi:10.1137/0702016 <http://dx.doi.org/10.1137/0702016>`_ ; 
        `Wikipedia article on SVD <http://en.wikipedia.org/wiki/Singular_value_decomposition>`_

